@@ -35,7 +35,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "gst.h"
-#include "gst-hig-dialog.h"
 #include "time-tool.h"
 
 #include "tz.h"
@@ -210,7 +209,7 @@ gst_time_update_date (GstTimeTool *tool, gint add)
 		{ 0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 }
 	};
 	GtkWidget *calendar;
-	gint day, month, year;
+	guint day, month, year;
 	gint days_in_month;
 	gboolean leap_year;
 
@@ -380,7 +379,7 @@ timezone_button_clicked (GtkWidget *w, gpointer data)
 
 	gtk_window_set_transient_for (GTK_WINDOW (d), GTK_WINDOW (dialog));
 
-	while (gtk_dialog_run (GTK_DIALOG (d)) != GTK_RESPONSE_CLOSE);
+	while (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_HELP);
 
 	tz_name     = e_tz_map_get_selected_tz_name (tzmap);
 	tz_location = e_tz_map_get_location_by_name (tzmap, tz_name);
@@ -409,7 +408,7 @@ server_button_clicked (GtkWidget *w, gpointer data)
 
 	gtk_window_set_transient_for (GTK_WINDOW (d), GTK_WINDOW (dialog));
 
-	while (gtk_dialog_run (GTK_DIALOG (d)) != GTK_RESPONSE_CLOSE);
+	while (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_HELP);
 	gtk_widget_hide (d);
 }
 
@@ -455,16 +454,16 @@ ntp_use_toggled (GtkWidget *w, GstDialog *dialog)
 		
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
 
-		message = gst_hig_dialog_new (GTK_WINDOW (dialog),
-					      GTK_DIALOG_MODAL,
-					      GST_HIG_MESSAGE_INFO,
-					      _("NTP support is not running"),
-					      _("Please run NTP support in the system to enable "
-						"synchronization of your local time server with internet time servers"),
-					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-					      NULL);
+		message = gtk_message_dialog_new (GTK_WINDOW (dialog),
+						  GTK_DIALOG_MODAL,
+						  GTK_MESSAGE_INFO,
+						  GTK_BUTTONS_CLOSE,
+						  _("NTP support is not installed"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
+							  _("Please install and activate NTP support in the system to enable "
+							    "synchronization of your local time server with "
+							    "internet time servers."));
 		gtk_dialog_run (GTK_DIALOG (message));
-
 		gtk_widget_destroy (message);
 		return;
 	}
@@ -709,7 +708,7 @@ void
 gst_time_set_full (GstTimeTool *time_tool, struct tm *tm)
 {
 	GtkWidget *calendar_widget;
-	gint day, month, year;
+	guint day, month, year;
 
 	calendar_widget = gst_dialog_get_widget (GST_TOOL (time_tool)->main_dialog, "calendar");
 	
