@@ -43,7 +43,7 @@
 #include "profiles-table.h"
 #include "search-bar/search-bar.h"
 
-extern XstTool *tool;
+extern GstTool *tool;
 
 extern GtkWidget *group_settings_all;
 extern GtkWidget *group_settings_members;
@@ -53,80 +53,133 @@ extern GtkWidget *groups_table;
 void
 on_showall_toggled (GtkToggleButton *toggle, gpointer user_data)
 {
-	XstDialogComplexity complexity = tool->main_dialog->complexity;
 	SearchBar *sb = SEARCH_BAR (g_object_get_data (G_OBJECT (tool->main_dialog), "SearchBar"));
 
 	/* we ought to clear previous searches */
 	search_bar_clear_search (sb);
-	
-	/* Only saves the change if we are in advanced mode, basic mode will be always FALSE (we don't need to save it) */
-	if (complexity == XST_DIALOG_ADVANCED) {
-		xst_conf_set_boolean (tool, "showall", gtk_toggle_button_get_active (toggle));
-	}
+
+	gst_conf_set_boolean (tool, "showall", gtk_toggle_button_get_active (toggle));
 	tables_update_content ();
 }
 
 /* Common stuff to users and groups tables */
-
-void
-counter (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-	int *cont = (int *) data;
-
-	(*cont) ++;
-}
-
 void
 on_table_clicked (GtkTreeSelection *selection, gpointer data)
 {
 	GtkTreeView *treeview;
 	int cont;
+	gboolean active;
 
 	treeview = (GtkTreeView *) data;
-	cont = 0;
-	gtk_tree_selection_selected_foreach (selection, counter , &cont);
+	cont = gtk_tree_selection_count_selected_rows (selection);
+	active = (cont > 0);
    
 	if (users_table == GTK_WIDGET (treeview))
-		actions_set_sensitive (NODE_USER, TRUE);
+		actions_set_sensitive (NODE_USER, active);
 	else if (groups_table == GTK_WIDGET (treeview))
-		actions_set_sensitive (NODE_GROUP, TRUE);
+		actions_set_sensitive (NODE_GROUP, active);
 	else
-		actions_set_sensitive (NODE_PROFILE, TRUE);
+		actions_set_sensitive (NODE_PROFILE, active);
 	
 	if (cont > 1)
 	{
 		if (users_table == GTK_WIDGET (treeview))
-			xst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_settings", FALSE);
+			gst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_settings", FALSE);
 		else if (groups_table == GTK_WIDGET (treeview))
-			xst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_settings", FALSE);
+			gst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_settings", FALSE);
 		else
-			xst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_settings", FALSE);
+			gst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_settings", FALSE);
 	}
 }
 
-/* Users Tab */
+static void
+do_popup_menu (GtkTreeView *treeview, GtkWidget *popup, GdkEventButton *event)
+{
+	GtkTreeSelection *selection;
+	GtkUIManager     *ui_manager;
+	gint              cont, button, event_time;
 
+	if (event) {
+		button     = event->button;
+		event_time = event->time;
+	} else {
+		button = 0;
+		event_time = gtk_get_current_event_time ();
+	}
+
+	selection = gtk_tree_view_get_selection (treeview);
+	cont = gtk_tree_selection_count_selected_rows (selection);
+	ui_manager = g_object_get_data (G_OBJECT (treeview), "ui-manager");
+
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (ui_manager, "/MainMenu/Properties"),
+				  cont == 1);
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (ui_manager, "/MainMenu/Delete"),
+				  cont > 0);
+
+	gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL,
+			button, event_time);
+}
+
+gboolean
+on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer gdata)
+{
+	GtkTreePath      *path;
+	GtkTreeSelection *selection;
+	GtkWidget        *popup;
+	gint              cont;
+
+	popup = (GtkWidget *) gdata;
+
+	if (event->type == GDK_2BUTTON_PRESS || event->type == GDK_3BUTTON_PRESS) {
+		if (GTK_WIDGET (treeview) == groups_table)
+			on_group_settings_clicked (NULL, NULL);
+		else if (GTK_WIDGET (treeview) == users_table)
+			on_user_settings_clicked (NULL, NULL);
+	}
+	
+	if (event->button == 3)	{
+		gtk_widget_grab_focus (GTK_WIDGET (treeview));
+		selection = gtk_tree_view_get_selection (treeview);
+		cont = gtk_tree_selection_count_selected_rows (selection);
+		
+		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL)) {
+			if (cont < 1) {
+				gtk_tree_selection_unselect_all (selection);
+				gtk_tree_selection_select_path (selection, path);
+			}
+
+			gtk_tree_path_free (path);
+
+			do_popup_menu (treeview, popup, event);
+		}
+
+		return TRUE;
+	}
+	
+	return FALSE;
+}
+
+gboolean
+on_table_popup_menu (GtkTreeView *treeview, GtkWidget *popup)
+{
+	do_popup_menu (treeview, popup, NULL);
+	return TRUE;
+}
+
+/* Users Tab */
 void
 on_user_new_clicked (GtkButton *button, gpointer user_data)
 {
 	ug_data *ud;
-	GtkWidget *notebook = xst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
+	GtkWidget *notebook = gst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 	ud = g_new (ug_data, 1);
 
 	ud->is_new = TRUE;
 	ud->table = NODE_USER;
 	ud->node = get_root_node (ud->table);
 
-	if (xst_dialog_get_complexity (tool->main_dialog) == XST_DIALOG_ADVANCED) {
-		/* user settings dialog */
-		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), TRUE);
-	} else {
-		/* user settings druid */
-		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
-	}
 	user_new_prepare (ud);
 }
 
@@ -134,7 +187,7 @@ void
 on_user_settings_clicked (GtkButton *button, gpointer user_data)
 {
 	ug_data *ud;
-	GtkWidget *notebook = xst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
+	GtkWidget *notebook = gst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
 
 	ud = g_new (ug_data, 1);
 
@@ -142,15 +195,6 @@ on_user_settings_clicked (GtkButton *button, gpointer user_data)
 	ud->table = NODE_USER;
 	ud->node = get_selected_row_node (NODE_USER);
 
-	if (xst_dialog_get_complexity (tool->main_dialog) == XST_DIALOG_ADVANCED) {
-		/* user settings dialog */
-		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), TRUE);
-	} else {
-		/* user settings simple dialog */
-		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
-	}
-
 	user_settings_prepare (ud);
 }
 
@@ -159,7 +203,7 @@ on_user_delete_clicked_foreach (GtkTreeModel *model, GtkTreePath *path, GtkTreeI
 {
 	xmlNodePtr node;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 	
 	gtk_tree_model_get (model, iter, COL_USER_POINTER, &node, -1);
 
@@ -178,7 +222,7 @@ on_user_delete_clicked (GtkButton *button, gpointer user_data)
 	/* At this point changed will be TRUE if any of the selected users has been deleted,
 	 * the apply button must be set sensitive and the table must be updated */
 	if (deleted == TRUE) {
-		xst_dialog_modify (tool->main_dialog);
+		gst_dialog_modify (tool->main_dialog);
 		users_table_update_content ();
 	}
 
@@ -186,27 +230,19 @@ on_user_delete_clicked (GtkButton *button, gpointer user_data)
 	actions_set_sensitive (NODE_USER, FALSE);
 }
 
-void
-on_profile_settings_dialog_clicked (GtkButton *button, gpointer user_data)
-{
-	GtkWidget *profile_window = xst_dialog_get_widget (tool->main_dialog, "profiles_dialog");
-	GtkWidget *option_menu = xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu");
-	
-	gtk_dialog_run (GTK_DIALOG (profile_window));
-	gtk_widget_hide (profile_window);
-}
-
 void
 on_profile_settings_users_dialog_clicked (GtkButton *button, gpointer user_data)
 {
-	GtkWidget *profile_window = xst_dialog_get_widget (tool->main_dialog, "profiles_dialog");
-	GtkWidget *option_menu = xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu");
+	GtkWidget    *profile_window = gst_dialog_get_widget (tool->main_dialog, "profiles_dialog");
+	GtkWidget    *combo = gst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu");
+	GtkTreeModel *model;
 	
-	gtk_dialog_run (GTK_DIALOG (profile_window));
+	while (gtk_dialog_run (GTK_DIALOG (profile_window)) == GTK_RESPONSE_HELP);
 	gtk_widget_hide (profile_window);
 
-	gtk_option_menu_remove_menu (GTK_OPTION_MENU (option_menu));
-	option_menu_add_profiles (option_menu);
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+	gtk_list_store_clear (GTK_LIST_STORE (model));
+	combo_add_profiles (combo);
 }
 
 /* Groups tab */
@@ -222,7 +258,7 @@ on_group_new_clicked (GtkButton *button, gpointer user_data)
 {
 	ug_data *gd;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 
 	gd = g_new (ug_data, 1);
 
@@ -252,7 +288,7 @@ on_group_delete_clicked_foreach (GtkTreeModel *model, GtkTreePath *path, GtkTree
 {
 	xmlNodePtr node;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 	
 	gtk_tree_model_get (model, iter, COL_GROUP_POINTER, &node, -1);
 
@@ -270,7 +306,7 @@ on_group_delete_clicked (GtkButton *button, gpointer user_data)
 
 	/* At this point changed will be true only if one of the selected groups has been deleted */
 	if (deleted == TRUE) {	
-		xst_dialog_modify (tool->main_dialog);
+		gst_dialog_modify (tool->main_dialog);
 		groups_table_update_content ();
 	}
 
@@ -278,6 +314,33 @@ on_group_delete_clicked (GtkButton *button, gpointer user_data)
 	actions_set_sensitive (NODE_GROUP, FALSE);
 }
 
+void
+on_popup_add_activate (GtkAction *action, gpointer callback_data)
+{
+	if (GTK_WIDGET (callback_data) == groups_table)
+		on_group_new_clicked (callback_data, NULL);
+	else if (GTK_WIDGET (callback_data) == users_table)
+		on_user_new_clicked (callback_data, NULL);
+}
+
+void
+on_popup_settings_activate (GtkAction *action, gpointer callback_data)
+{
+	if (GTK_WIDGET (callback_data) == groups_table)
+		on_group_settings_clicked (callback_data, NULL);
+	else if (GTK_WIDGET (callback_data) == users_table)
+		on_user_settings_clicked (callback_data, NULL);
+}
+
+void
+on_popup_delete_activate (GtkAction *action, gpointer callback_data)
+{
+	if (GTK_WIDGET (callback_data) == groups_table)
+		on_group_delete_clicked (callback_data, NULL);
+	else if (GTK_WIDGET (callback_data) == users_table)
+		on_user_delete_clicked (callback_data, NULL);
+}
+
 #ifdef NIS
 /* Network tab. */
 
@@ -288,7 +351,7 @@ on_network_delete_clicked (GtkWidget *button, gpointer user_data)
 	gboolean delete = FALSE;
 	gint tbl = -1;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 
 	node = get_selected_node ();
 
@@ -307,9 +370,9 @@ on_network_delete_clicked (GtkWidget *button, gpointer user_data)
 
 	if (delete)
 	{
-		xst_dialog_modify (tool->main_dialog);
+		gst_dialog_modify (tool->main_dialog);
 		if (delete_selected_node (tbl))
-			xst_xml_element_destroy (node);
+			gst_xml_element_destroy (node);
 
 		actions_set_sensitive (NODE_GROUP, FALSE);
 	}
@@ -318,7 +381,7 @@ on_network_delete_clicked (GtkWidget *button, gpointer user_data)
 void
 on_network_user_new_clicked (GtkButton *button, gpointer user_data)
 {
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 
 	user_settings_prepare (get_root_node (NODE_NET_USER));
 }
@@ -328,7 +391,7 @@ on_network_group_new_clicked (GtkButton *button, gpointer user_data)
 {
 	ug_data *ud;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 
 	ud = g_new (ug_data, 1);
 
@@ -353,13 +416,15 @@ void
 on_user_settings_dialog_show (GtkWidget *widget, gpointer user_data)
 {
 	/* Set focus to user name entry. */
-	gtk_widget_grab_focus (xst_dialog_get_widget (tool->main_dialog, "user_settings_name"));
+	gtk_widget_grab_focus (gst_dialog_get_widget (tool->main_dialog, "user_settings_name"));
 }
 
-void
+gboolean
 on_user_settings_dialog_delete_event (GtkWidget *w, gpointer user_data)
 {
 	user_settings_dialog_close ();
+
+	return TRUE;
 }
 
 void
@@ -368,14 +433,14 @@ on_user_settings_ok_clicked (GtkButton *button, gpointer data)
 	GtkWidget *widget;
 	ug_data *ud;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	ud = g_object_get_data (G_OBJECT (widget), "data");
 
 	if (user_update (ud))
 	{
-		xst_dialog_modify (tool->main_dialog);
+		gst_dialog_modify (tool->main_dialog);
 		user_settings_dialog_close ();
 	}
 }
@@ -386,18 +451,18 @@ on_user_settings_passwd_random_new (GtkButton *button, gpointer data)
 	gchar *passwd;
 
 	passwd = passwd_get_random ();
-	gtk_entry_set_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_random_entry")), passwd);
+	gtk_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_passwd_random_entry")), passwd);
 	g_free (passwd);
 }
 
 void
 on_user_settings_passwd_toggled (GtkToggleButton *toggle, gpointer data)
 {
-	GtkWidget *user_passwd_random_new = xst_dialog_get_widget (tool->main_dialog, "user_passwd_random_new");
-	GtkWidget *user_passwd_random_entry = xst_dialog_get_widget (tool->main_dialog, "user_passwd_random_entry");
-	GtkWidget *user_passwd_entry1 = xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1");
-	GtkWidget *user_passwd_entry2 = xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2");
-	GtkToggleButton *pwd_manual = GTK_TOGGLE_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_manual"));
+	GtkWidget *user_passwd_random_new = gst_dialog_get_widget (tool->main_dialog, "user_passwd_random_new");
+	GtkWidget *user_passwd_random_entry = gst_dialog_get_widget (tool->main_dialog, "user_passwd_random_entry");
+	GtkWidget *user_passwd_entry1 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1");
+	GtkWidget *user_passwd_entry2 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2");
+	GtkToggleButton *pwd_manual = GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual"));
 	
 
 	if (gtk_toggle_button_get_active (pwd_manual)) {
@@ -420,18 +485,29 @@ on_user_settings_passwd_toggled (GtkToggleButton *toggle, gpointer data)
 void
 on_user_settings_profile_changed (GtkWidget *widget, gpointer data)
 {
-	xmlNodePtr profile = data;
+	GtkTreeModel *model;
+	GtkTreeIter   iter;
+	xmlNodePtr    profile;
 
-	user_set_profile (profile);
+	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter)) {
+		model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
+		gtk_tree_model_get (model, &iter, 1, &profile, -1);
+		user_set_profile (profile);
+	}
+}
+
+void
+on_user_settings_show_help (GtkButton *button, gpointer data)
+{
+	gst_tool_show_help (tool, "tool-add-new-user");
 }
 
 /* Group settings callbacks */
-
 void
 on_group_settings_dialog_show (GtkWidget *widget, gpointer user_data)
 {
 	/* Set focus to user name entry. */
-	gtk_widget_grab_focus (xst_dialog_get_widget (tool->main_dialog, "group_settings_name"));
+	gtk_widget_grab_focus (gst_dialog_get_widget (tool->main_dialog, "group_settings_name"));
 }
 
 void
@@ -446,23 +522,29 @@ on_group_settings_ok_clicked (GtkButton *button, gpointer user_data)
 	GtkWidget *widget;
 	ug_data *gd;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 
-	widget = xst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
+	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
 	gd = g_object_get_data (G_OBJECT (widget), "data");
 
 	if (group_update (gd))
 	{
-		xst_dialog_modify (tool->main_dialog);
+		gst_dialog_modify (tool->main_dialog);
 		group_settings_dialog_close ();
 	}
 }
 
+void
+on_group_settings_show_help (GtkButton *button, gpointer data)
+{
+	gst_tool_show_help (tool, "tool-add-new-group");
+}
+
 /* Profile settings dialog callbacks */
 void
 on_profile_settings_dialog_delete_event (GtkWidget *widget, gpointer data)
 {
-	GtkWidget *dialog = xst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
+	GtkWidget *dialog = gst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
 	xmlNodePtr node = g_object_get_data (G_OBJECT (dialog), "data");
 
 	if (node != NULL) {
@@ -477,18 +559,20 @@ on_profile_settings_dialog_delete_event (GtkWidget *widget, gpointer data)
 void
 on_profile_settings_ok_clicked (GtkButton *button, gpointer data)
 {
-	GtkWidget *dialog = xst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
-	xmlNodePtr node = g_object_get_data (G_OBJECT (dialog), "data");
-	gchar *error = profile_settings_check ();
+	GtkWidget *dialog = gst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
+	xmlNodePtr node   = g_object_get_data (G_OBJECT (dialog), "data");
+	gchar *error      = profile_settings_check ();
 
 	if (error != NULL) {
 		/* the profile cannot be added/modified, show the error and exit */
-		show_error_message ("profile_settings_dialog", error);
+		show_error_message ("profile_settings_dialog",
+				    _("Error saving profile"),
+				    error);
 	} else {
 		/* the profile is OK, we can add/modify it */
 		if (node == NULL) {
 			/* it's a new profile, we have to create a node before saving changes */
-			node = xst_xml_element_add (get_root_node (NODE_PROFILE), "profile");
+			node = gst_xml_element_add (get_root_node (NODE_PROFILE), "profile");
 		}
 
 		profile_settings_save_data (node);
@@ -498,24 +582,37 @@ on_profile_settings_ok_clicked (GtkButton *button, gpointer data)
 
 		profiles_table_update_content ();
 
-		xst_dialog_modify (tool->main_dialog);
+		/* mark dialog buttons as unsensitive */
+		actions_set_sensitive (NODE_PROFILE, FALSE);
+
+		gst_dialog_modify (tool->main_dialog);
 	}
 }
 
-/* Profile settings callbacks */
+void
+on_profile_settings_show_help (GtkButton *button, gpointer data)
+{
+	gst_tool_show_help (tool, "tool-add-new-profile");
+}
 
+/* Profile settings callbacks */
 void
 on_profile_new_clicked (GtkButton *button, gpointer data)
 {
-	GtkWidget *dialog = xst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
-	GtkWidget *groups_option_menu = xst_dialog_get_widget (tool->main_dialog, "profile_settings_group");
-	GtkWidget *shells_combo = xst_dialog_get_widget (tool->main_dialog, "profile_settings_shell");
+	GtkWidget *dialog = gst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
+	GtkWidget *groups_option_menu = gst_dialog_get_widget (tool->main_dialog, "profile_settings_group");
+	GtkWidget *shells_combo = gst_dialog_get_widget (tool->main_dialog, "profile_settings_shell");
+	GtkWidget *privileges = gst_dialog_get_widget (tool->main_dialog, "profile_privileges");
 
 	combo_add_shells (shells_combo);
-	option_menu_add_groups (groups_option_menu, TRUE);
+	combo_add_groups (groups_option_menu, TRUE);
+	populate_privileges_table (privileges, NULL);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Create New profile"));
 
+	if (!GTK_WIDGET_VISIBLE (gst_dialog_get_widget (tool->main_dialog, "user_optional_settings")))
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "profile_settings_password"));
+
 	gtk_widget_show (dialog);
 }
 
@@ -523,10 +620,11 @@ on_profile_new_clicked (GtkButton *button, gpointer data)
 void
 on_profile_settings_clicked (GtkButton *button, gpointer data)
 {
-	GtkWidget *groups_option_menu = xst_dialog_get_widget (tool->main_dialog, "profile_settings_group");
-	GtkWidget *shells_combo = xst_dialog_get_widget (tool->main_dialog, "profile_settings_shell");
-	GtkWidget *dialog =xst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
-	GtkWidget *profiles_table = xst_dialog_get_widget (tool->main_dialog, "profiles_table");
+	GtkWidget *groups_option_menu = gst_dialog_get_widget (tool->main_dialog, "profile_settings_group");
+	GtkWidget *shells_combo = gst_dialog_get_widget (tool->main_dialog, "profile_settings_shell");
+	GtkWidget *dialog = gst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
+	GtkWidget *profiles_table = gst_dialog_get_widget (tool->main_dialog, "profiles_table");
+	GtkWidget *privileges = gst_dialog_get_widget (tool->main_dialog, "profile_privileges");
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (profiles_table));
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
@@ -539,17 +637,21 @@ on_profile_settings_clicked (GtkButton *button, gpointer data)
 	gtk_tree_model_get (model, &iter, COL_PROFILE_POINTER, &node, -1);
 
 	combo_add_shells (shells_combo);
-	option_menu_add_groups (groups_option_menu, TRUE);
+	combo_add_groups (groups_option_menu, TRUE);
 	profile_settings_set_data (node);
+	populate_privileges_table_from_profile (privileges, node);
 
 	g_object_set_data (G_OBJECT (dialog), "data", node);
 
-	profile_name = xst_xml_get_child_content (node, "name");
+	profile_name = gst_xml_get_child_content (node, "name");
 	window_title = g_strdup_printf (_("Settings for profile %s"), profile_name);
 	gtk_window_set_title (GTK_WINDOW (dialog), window_title);
 	g_free (profile_name);
 	g_free (window_title);
 
+	if (!GTK_WIDGET_VISIBLE (gst_dialog_get_widget (tool->main_dialog, "user_optional_settings")))
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "profile_settings_password"));
+
 	gtk_widget_show (dialog);
 }
 
@@ -558,7 +660,7 @@ on_profile_delete_clicked_foreach (GtkTreeModel *model, GtkTreePath *path, GtkTr
 {
 	xmlNodePtr node;
 
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 	
 	gtk_tree_model_get (model, iter, COL_PROFILE_POINTER, &node, -1);
 
@@ -569,7 +671,7 @@ on_profile_delete_clicked_foreach (GtkTreeModel *model, GtkTreePath *path, GtkTr
 void
 on_profile_delete_clicked (GtkButton *button, gpointer user_data)
 {
-	GtkWidget *profiles_table = xst_dialog_get_widget (tool->main_dialog, "profiles_table");
+	GtkWidget *profiles_table = gst_dialog_get_widget (tool->main_dialog, "profiles_table");
 	GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (profiles_table));
 	gboolean deleted = FALSE;
 	
@@ -578,7 +680,7 @@ on_profile_delete_clicked (GtkButton *button, gpointer user_data)
 	/* At this point changed will be TRUE if any of the selected users has been deleted,
 	 * the apply button must be set sensitive and the table must be updated */
 	if (deleted == TRUE) {
-		xst_dialog_modify (tool->main_dialog);
+		gst_dialog_modify (tool->main_dialog);
 		profiles_table_update_content ();
 	}
 
@@ -587,56 +689,42 @@ on_profile_delete_clicked (GtkButton *button, gpointer user_data)
 }
 
 /* general callbacks */
-
 void
-on_add_remove_button_clicked (GtkButton *button, gpointer user_data)
+on_add_remove_button_clicked (GtkButton *button, gpointer data)
 {
 	GtkTreeView *in, *out;
 	GtkTreeSelection *selection;
-	GtkTreeIter iter;
-	GtkTreeModel *model;
-	GList *in_list, *out_list;
-	GList *element;
+	GtkTreeIter iter_in, iter_out;
+	GtkTreeModel *model_in, *model_out;
+	gchar *group;
+	gboolean valid;
 	
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 	
 	in = g_object_get_data (G_OBJECT (button), "in");
 	out = g_object_get_data (G_OBJECT (button), "out");
 	
 	g_return_if_fail (in != NULL || out != NULL);
 
-	in_list = g_object_get_data (G_OBJECT (in), "list");
-	out_list = g_object_get_data (G_OBJECT (out), "list");
-	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (in));
-	model = gtk_tree_view_get_model (in);
-	gtk_tree_model_get_iter_first (model, &iter);
-	
-	do {
-		if (gtk_tree_selection_iter_is_selected (selection, &iter)) {
-			/* gets the user that is being removed from the 'in' list */
-			gtk_tree_model_get (model, &iter,
-	                                    1, &element,
-	                                    -1);
-			/* adds the user to the 'out' list */
-                        out_list = g_list_insert_sorted (out_list, element->data, my_strcmp);
-			
-			/* removes the user from the 'in' list */
-			in_list = g_list_remove (in_list, element->data);
+	model_in = gtk_tree_view_get_model (in);
+	model_out = gtk_tree_view_get_model (out);
+
+	valid = gtk_tree_model_get_iter_first (model_in, &iter_in);
+
+	while (valid) {
+		if (gtk_tree_selection_iter_is_selected (selection, &iter_in)) {
+			gtk_tree_model_get (model_in, &iter_in, 0, &group, -1);
+
+			gtk_tree_store_append (GTK_TREE_STORE (model_out), &iter_out, NULL);
+			gtk_tree_store_set (GTK_TREE_STORE (model_out), &iter_out, 0, group, -1);
+
+			valid = gtk_tree_store_remove (GTK_TREE_STORE (model_in), &iter_in);
+		} else {
+			valid = gtk_tree_model_iter_next (model_in, &iter_in);
 		}
-	} while (gtk_tree_model_iter_next (model, &iter));
-	
-	/* reattach GLists to GtkTreeViews */
-	g_object_set_data (G_OBJECT (in), "list", in_list);
-	g_object_set_data (G_OBJECT (out), "list", out_list);
+	}
 
-	/* Refresh the 'in' and 'out' lists */
-	clear_gtk_tree_list (in);
-	clear_gtk_tree_list (out);
-	populate_gtk_tree_list (in, in_list);
-	populate_gtk_tree_list (out, out_list);
-	
-	/* sets unsensitive the button again */
 	gtk_widget_set_sensitive (GTK_WIDGET (button), FALSE);
 }
 
@@ -651,10 +739,60 @@ on_list_select_row (GtkTreeSelection *selection, gpointer data)
 	list = gtk_tree_selection_get_tree_view (selection);
 	button = g_object_get_data (G_OBJECT (list), "button");
 	
-	widget = xst_dialog_get_widget (tool->main_dialog, button);
+	widget = gst_dialog_get_widget (tool->main_dialog, button);
 	gtk_widget_set_sensitive (widget, TRUE);
 }
 
+void
+on_list_drag_data_get (GtkTreeView *treeview,
+		       GdkDragContext *context,
+		       GtkSelectionData *selection,
+		       guint info,
+		       guint time,
+		       gpointer data)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
+	GtkTreePath *path;
+	GtkTreeIter iter;
+	gchar *group;
+
+	gtk_tree_view_get_cursor (treeview, &path, NULL);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter, 0, &group, -1);
+	
+	gtk_selection_data_set (selection,
+				gdk_atom_intern ("x/selection-data", FALSE),
+				8, group, strlen (group) + 1);
+}
+
+void
+on_list_drag_data_received (GtkTreeView *dest_treeview,
+			    GdkDragContext *context,
+			    gint x,
+			    gint y,
+			    GtkSelectionData *selection,
+			    guint info,
+			    guint time,
+			    gpointer data)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (dest_treeview);
+	GtkTreeIter iter;
+
+	if (selection->data == NULL || selection->length == -1) {
+		gtk_drag_finish (context, FALSE, FALSE, GDK_CURRENT_TIME);
+		return;
+	}
+
+	gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
+	gtk_tree_store_set (GTK_TREE_STORE (model),
+			    &iter,
+			    0, selection->data,
+			    -1);
+	
+	gtk_drag_finish (context, TRUE, TRUE, GDK_CURRENT_TIME);
+	gst_dialog_modify (tool->main_dialog);
+}
+
 /* Helpers .*/
 
 void
@@ -663,26 +801,26 @@ actions_set_sensitive (gint table, gboolean state)
 	switch (table)
 	{
 	case NODE_USER:
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_new",      TRUE);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_delete",   state);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_settings", state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_new",      TRUE);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_delete",   state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_settings", state);
 		break;
 	case NODE_GROUP:
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_new",      TRUE);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_delete",   state);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_settings", state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_new",      TRUE);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_delete",   state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_settings", state);
 		break;
 /*	case NODE_NET_USER:
 	case NODE_NET_GROUP:
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_group_new", TRUE);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_user_new",  TRUE);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_delete",    state);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_settings",  state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_group_new", TRUE);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_user_new",  TRUE);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_delete",    state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "network_settings",  state);
 		break;*/
 	case NODE_PROFILE:
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_new",      TRUE);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_settings", state);
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_delete",   state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_new",      TRUE);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_settings", state);
+		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "profile_delete",   state);
 		break;
 	default:
 		g_warning ("actions_set_sensitive: Shouldn't be here.");
